@@ -15,4 +15,4 @@ from .redis_server import QRedisServer
 from .mysql_server import QMysqlServer
 from .vnc_server import QVNCServer
 from .qbsniffer import QBSniffer
-from .helper import server_arguments, clean_all, kill_servers, get_free_port, close_port_wrapper, kill_server_wrapper, setup_logger, disable_logger, postgres_class
+from .helper import server_arguments, clean_all, kill_servers, get_free_port, close_port_wrapper, kill_server_wrapper, setup_logger, disable_logger, postgres_class, get_running_servers
